@@ -13,12 +13,11 @@ import ast
 import math
 import numpy
 
-from . import builtins
 from . import site_config
 from .symboltable import SymbolTable, Group, isgroup
 from .inputText import InputText, BLANK_TEXT
 from .larchlib import (LarchExceptionHolder, ReturnedNone,
-                       Procedure, StdWriter, enable_plugins)
+                       Procedure, StdWriter)
 from .closure import Closure
 from .utils import debugtime
 
@@ -98,7 +97,7 @@ class Interpreter:
                        'unaryop', 'while')
 
     def __init__(self, symtable=None, input=None, writer=None,
-                 with_plugins=False, historyfile=None, maxhistory=5000):
+                 historyfile=None, maxhistory=5000):
         self.symtable   = symtable or SymbolTable(larch=self)
 
         self.input      = input or InputText(_larch=self,
@@ -119,8 +118,9 @@ class Interpreter:
         setattr(mathgroup, 'np', numpy)
 
         # system-specific settings
-        enable_plugins()
         site_config.system_settings()
+        from larch import builtins
+
         for sym in builtins.from_math:
             setattr(mathgroup, sym, getattr(math, sym))
 
@@ -128,12 +128,14 @@ class Interpreter:
             setattr(builtingroup, sym, __builtins__[sym])
 
         for sym in builtins.from_numpy:
-            try:
-                setattr(mathgroup, sym, getattr(numpy, sym))
-            except AttributeError:
-                pass
-        for fname, sym in list(builtins.numpy_renames.items()):
-            setattr(mathgroup, fname, getattr(numpy, sym))
+            val = getattr(numpy, sym, None)
+            if val is not None:
+                setattr(mathgroup, sym, val)
+
+        for fname, sym in builtins.numpy_renames.items():
+            val = getattr(numpy, sym, None)
+            if val is not None:
+                setattr(mathgroup, fname, val)
 
         for name, value in builtins.constants.items():
             setattr(mathgroup, name, value)
@@ -148,8 +150,11 @@ class Interpreter:
                 group = self.symtable.set_symbol(groupname,
                                                  value=Group(__name__=groupname))
             for fname, fcn in list(entries.items()):
-                setattr(group, fname,
-                        Closure(func=fcn, _larch=self, _name=fname))
+                if callable(fcn):
+                    setattr(group, fname,
+                            Closure(func=fcn, _larch=self, _name=fname))
+                else:
+                    setattr(group, fname, fcn)
 
         self.symtable._sys.core_groups = core_groups
         self.symtable._fix_searchGroups(force=True)
@@ -163,9 +168,6 @@ class Interpreter:
             if callable(fcn):
                 fcn(_larch=self)
 
-        for grp in builtins.init_groups:
-            self.symtable._sys.saverestore_groups.append(grp)
-
         for groupname, docstring in builtins.init_moddocs.items():
             group = self.symtable.get_group(groupname)
             group.__doc__ = docstring
@@ -175,21 +177,6 @@ class Interpreter:
         self.node_handlers = dict(((node, getattr(self, "on_%s" % node))
                                    for node in self.supported_nodes))
 
-        if with_plugins: # add all plugins in standard plugins folder
-            print("WARNING: Plugins are deprecated and will be removed in 2022")
-            plugins_dir = os.path.join(site_config.user_larchdir, 'plugins')
-            loaded_plugins = []
-            for pname in sorted(os.listdir(plugins_dir)):
-                if pname not in loaded_plugins:
-                    pdir = os.path.join(plugins_dir, pname)
-                    if os.path.isdir(pdir):
-                        builtins.add_plugin(pdir, _larch=self)
-                        loaded_plugins.append(pname)
-
-
-    def add_plugin(self, mod, **kws):
-        """add plugin components from plugin directory"""
-        builtins.add_plugin(mod, _larch=self, **kws)
 
     def unimplemented(self, node):
         "unimplemented nodes"
@@ -635,18 +622,27 @@ class Interpreter:
         for tnode in node.targets:
             if tnode.ctx.__class__ != ast.Del:
                 break
-            children = []
-            while tnode.__class__ == ast.Attribute:
-                children.append(tnode.attr)
-                tnode = tnode.value
-
-            if tnode.__class__ == ast.Name:
-                children.append(tnode.id)
-                children.reverse()
-                self.symtable.del_symbol('.'.join(children))
+            if tnode.__class__ == ast.Subscript:
+                try:
+                    parent = self.run(tnode.value)
+                    if hasattr(parent, '__delitem__') and tnode.slice.__class__ == ast.Constant:
+                        child = tnode.slice.value
+                        parent.__delitem__(child)
+                except:
+                    msg = "could not delete symbol"
+                    self.raise_exception(node, msg=msg)
             else:
-                msg = "could not delete symbol"
-                self.raise_exception(node, msg=msg)
+                children = []
+                while tnode.__class__ == ast.Attribute:
+                    children.append(tnode.attr)
+                    tnode = tnode.value
+                if tnode.__class__ == ast.Name:
+                    children.append(tnode.id)
+                    children.reverse()
+                    self.symtable.del_symbol('.'.join(children))
+                else:
+                    msg = "could not delete symbol"
+                    self.raise_exception(node, msg=msg)
 
     def on_unaryop(self, node):    # ('op', 'operand')
         "unary operator"
