@@ -13,7 +13,7 @@ Requirements
 """
 
 __author__ = ["Mauro Rovezzi", "Matt Newville"]
-__version__ = "larch_0.9.57"
+__version__ = "larch_0.9.66"
 
 import os
 import copy
@@ -23,7 +23,7 @@ import collections
 import numpy as np
 import h5py
 from silx.io.utils import open as silx_open
-from silx.io.convert import write_to_h5, _is_commonh5_group
+from silx.io.convert import write_to_h5
 
 # from scipy.interpolate import interp1d
 # from scipy.ndimage import map_coordinates
@@ -160,6 +160,38 @@ def update_nested(d, u):
     return d
 
 
+def _atoi(text):
+    return int(text) if text.isdigit() else text
+
+
+def natural_keys(text):
+    """
+    FROM: https://stackoverflow.com/questions/5967500/how-to-correctly-sort-a-string-with-a-number-inside
+
+    alist.sort(key=natural_keys) sorts in human order
+    http://nedbatchelder.com/blog/200712/human_sorting.html
+    (See Toothy's implementation in the comments)
+
+    Usage
+    -----
+
+    alist=[
+        "something1",
+        "something12",
+        "something17",
+        "something2",
+        "something25",
+        "something29"]
+
+    alist.sort(key=natural_keys)
+    print(alist)
+
+    """
+    import re
+
+    return [_atoi(c) for c in re.split(r"(\d+)", text)]
+
+
 # ==================================================================
 # CLASS BASED ON SPECH5 (CURRENT/RECOMMENDED)
 # ==================================================================
@@ -183,7 +215,9 @@ class DataSourceSpecH5(object):
             'silx' : default
             'spec2nexus' : as converted by spec2nexus
         verbose : bool [False]
-            if True it lowers the logger level to INFO, othewise WARNING by default
+            if True it lowers the logger level to INFO
+            if 'debug', it lowers the logger level to DEBUG (for testing)
+            othewise WARNING by default
         """
         if logger is None:
             from larch.utils.logging import getLogger
@@ -196,6 +230,9 @@ class DataSourceSpecH5(object):
         if verbose:
             self._logger.setLevel("INFO")
 
+        if isinstance(verbose, str) and verbose.lower() == "debug":
+            self._logger.setLevel("DEBUG")
+
         self._fname = fname
         self._sourcefile = None
         self._sourcefile_type = None
@@ -252,7 +289,9 @@ class DataSourceSpecH5(object):
                 _iscn = 0
                 self.set_scan(self._scans[_iscn][0])  # set the first scan at init
                 while len(self.get_counters()) == 1:
-                    self._logger.warning(f"not enough data in scan {_iscn+1} '{self.get_title()}'")
+                    self._logger.warning(
+                        f"not enough data in scan {_iscn+1} '{self.get_title()}'"
+                    )
                     _iscn += 1
                     self.set_scan(self._scans[_iscn][0])
             except Exception as e:
@@ -282,7 +321,7 @@ class DataSourceSpecH5(object):
              scan address
         """
         if scan is not None:
-            self.set_scan(scan)        
+            self.set_scan(scan)
         if self._scangroup is None:
             raise AttributeError(
                 "Group/Scan not selected -> use 'self.set_scan()' first"
@@ -308,7 +347,7 @@ class DataSourceSpecH5(object):
 
     def set_scan(self, scan, scan_idx=1, group_url=None, scan_kws=None):
         """Select a given scan
-        
+
         Parameters
         ----------
         scan : int or str
@@ -327,6 +366,16 @@ class DataSourceSpecH5(object):
         """
         if scan_kws is not None:
             self._scan_kws = update_nested(self._scan_kws, scan_kws)
+
+        if isinstance(scan, int):
+            scn = f"{scan}_"
+            for slist in self._scans:
+                sl0 = slist[0]
+                if scn in sl0.lower():
+                    self._logger.debug(f"scan '{scan}' -> '{sl0}'")
+                    scan = sl0
+                    break
+
         if scan in self._scans_names:
             self._scan_str = scan
             self._scan_n = self._scans_names.index(scan)
@@ -374,7 +423,6 @@ class DataSourceSpecH5(object):
             self._scan_title = None
             self._logger.error(f"'{self._scan_url}' is not valid")
 
-
     def _list_from_url(self, url_str):
         """Utility method to get a list from a scan url
 
@@ -418,7 +466,10 @@ class DataSourceSpecH5(object):
         """
         allscans = []
         for sn in self._sourcefile["/"].keys():
-            sg = self._sourcefile[sn]
+            try:
+                sg = self._sourcefile[sn]
+            except KeyError:
+                continue  # broken HDF5 link
             try:
                 allscans.append(
                     [
@@ -429,7 +480,7 @@ class DataSourceSpecH5(object):
                 )
             except KeyError:
                 self._logger.error(f"'{sn}' is a datagroup!")
-                #go one level below and try take first dataset only
+                # go one level below and try take first dataset only
                 dt0 = list(sg.keys())[0]
                 sgg = sg[dt0]
                 try:
@@ -442,8 +493,14 @@ class DataSourceSpecH5(object):
                         ]
                     )
                 except Exception:
-                    self._logger.error(f"{scname} does not have standard title/time URLs")
+                    self._logger.error(
+                        f"{scname} does not have standard title/time URLs"
+                    )
                     allscans.append([None, None, None])
+
+        # sort scan in natural/human order
+        allscans.sort(key=lambda row: natural_keys(row[0]))
+
         return allscans
 
     def get_motors(self):
@@ -631,7 +688,7 @@ class DataSourceSpecH5(object):
         Parameters
         ----------
         scan  : str, int, or None
-             scan address 
+             scan address
         datatype : str
             type of data, e.g. 'raw', 'xas'
 
@@ -732,11 +789,13 @@ class DataSourceSpecH5(object):
             try:
                 from sloth.utils.bragg import ang2kev
             except ImportError:
+
                 def ang2kev(theta, d):
                     from larch.utils.physical_constants import PLANCK_HC
+
                     theta = np.deg2rad(theta)
                     wlen = 2 * d * np.sin(theta)
-                    return (PLANCK_HC / wlen) / 1000.
+                    return (PLANCK_HC / wlen) / 1000.0
 
             bragg_ax = to_energy["bragg_ax"]
             bragg_ax_type = to_energy["bragg_ax_type"]
@@ -927,8 +986,6 @@ class DataSourceSpecH5(object):
                 _scangroup = self._scangroup
                 if _scangroup is None:
                     continue
-                if not _is_commonh5_group(_scangroup):
-                    self._logger.error("scan '%s' is not commonh5 group", scn)
                 if group is not None:
                     _h5path = f"{h5path}{group}/{self._scan_str}/"
                 else:
