@@ -5,8 +5,10 @@ utilities for larch
 from __future__ import print_function
 import re
 import sys
-from base64 import b64encode, b32encode
+import os
+import uuid
 import hashlib
+from base64 import b64encode, b32encode
 import random
 from distutils.version import StrictVersion
 
@@ -16,6 +18,7 @@ def bytes2str(s):
     elif isinstance(s, bytes):
         return s.decode(sys.stdout.encoding)
     return str(s, sys.stdout.encoding)
+
 def str2bytes(s):
     'string to byte conversion'
     if isinstance(s, bytes):
@@ -23,13 +26,20 @@ def str2bytes(s):
     return bytes(s, sys.stdout.encoding)
 
 
-RESERVED_WORDS = ('and', 'as', 'assert', 'break', 'class', 'continue',
-                  'def', 'del', 'elif', 'else', 'eval', 'except', 'exec',
-                  'execfile', 'finally', 'for', 'from', 'global', 'if',
-                  'import', 'in', 'is', 'lambda', 'not', 'or', 'pass',
-                  'print', 'raise', 'return', 'try', 'while', 'with',
-                  'group', 'end', 'endwhile', 'endif', 'endfor', 'endtry',
-                  'enddef', 'True', 'False', 'None')
+def strict_ascii(s, replacement='_'):
+    """for string to be truly ASCII with all characters below 128"""
+
+    t = bytes(s, 'UTF-8')
+    return ''.join([chr(a) if a < 128 else replacement for a in t])
+
+RESERVED_WORDS = ('False', 'None', 'True', 'and', 'as', 'assert', 'async',
+                  'await', 'break', 'class', 'continue', 'def', 'del', 'elif',
+                  'else', 'end', 'enddef', 'endfor', 'endif', 'endtry',
+                  'endwhile', 'eval', 'except', 'exec', 'execfile', 'finally',
+                  'for', 'from', 'global', 'group', 'if', 'import', 'in', 'is',
+                  'lambda', 'nonlocal', 'not', 'or', 'pass', 'print', 'raise',
+                  'return', 'try', 'while', 'with', 'yield')
+
 
 NAME_MATCH = re.compile(r"[a-zA-Z_][a-zA-Z0-9_]*(\.[a-zA-Z_][a-zA-Z0-9_]*)*$").match
 VALID_SNAME_CHARS = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_'
@@ -177,11 +187,17 @@ def unique_name(name, nlist, max=1000):
 def isNumber(num):
     "input is a number"
     try:
-        cnum = complex(num)
+        x = float(num)
         return True
-    except ValueError:
+    except (TypeError, ValueError):
         return False
 
+def asfloat(x):
+    """try to convert value to float, or fail gracefully"""
+    return float(x) if isNumber(x) else x
+
+
+
 def isLiteralStr(inp):
     "is a literal string"
     return ((inp.startswith("'") and inp.endswith("'")) or
@@ -233,6 +249,14 @@ def b64hash(s):
     _hash.update(str2bytes(s))
     return bytes2str(b64encode(_hash.digest()))
 
+def get_sessionid():
+    """get 8 character string encoding machine name and process id"""
+    _hash = hashlib.sha256()
+    _hash.update(f"{uuid.getnode():d} {os.getpid():d}".encode('ASCII'))
+    out = b64encode(_hash.digest()).decode('ASCII')[3:11]
+    return out.replace('/', '-').replace('+', '=')
+
+
 def file2groupname(filename, slen=5, symtable=None):
     """create a group name based of filename
     the group name will have a string component of
@@ -268,3 +292,34 @@ def file2groupname(filename, slen=5, symtable=None):
             if scount > 1000:
                 raise ValueError("exhausted unique group names")
     return gname
+
+
+def break_longstring(s, maxlen=90, n1=20):
+    """breaks a long string into a list of smaller strings,
+    broken at commas, space, tab, period, or slash
+
+    returns a list of strings, even if length 1"""
+
+    minlen = maxlen-n1
+
+    if len(s) < maxlen:
+        return [s]
+    out = []
+    while len(s) > maxlen:
+        icomma = s[minlen:].find(',')
+        ispace = s[minlen:].find(' ')
+        itab   = s[minlen:].find('\t')
+        idot   = s[minlen:].find('.')
+        islash = s[minlen:].find('/')
+        ibreak =  -1
+        if icomma > 0:    ibreak = icomma
+        elif ispace > 0:  ibreak = ispace
+        elif itab > 0:    ibreak = itab
+        elif idot > 0:    ibreak = idot
+        elif islash > 0:  ibreak = islash
+        if ibreak < 0:
+            ibreak = maxlen
+        out.append(s[:ibreak+minlen+1])
+        s = s[ibreak+minlen+1:]
+    out.append(s)
+    return out
