@@ -42,8 +42,10 @@ ELEM_LIST = ('H', 'He', 'Li', 'Be', 'B', 'C', 'N', 'O', 'F', 'Ne', 'Na',
 
 EDGE_LIST = ('K', 'L3', 'L2', 'L1', 'M5', 'M4', 'M3')
 
+NORM_MU = 'Normalized \u03BC(E)'
+
 DEGLITCH_PLOTS = {'Raw \u03BC(E)': 'mu',
-                  'Normalized \u03BC(E)': 'norm',
+                  NORM_MU: 'norm',
                   '\u03c7(E)': 'chie',
                   '\u03c7(E)*(E-E_0)': 'chiew'}
 
@@ -119,9 +121,9 @@ class OverAbsorptionDialog(wx.Dialog):
 
         self.set_default_elem_edge(self.dgroup)
 
-        wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
-                               action=self.on_apply)
-        SetTip(wids['apply'], 'Save corrected data, overwrite current arrays')
+        #wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
+        #                       action=self.on_apply)
+        #SetTip(wids['apply'], 'Save corrected data, overwrite current arrays')
 
         wids['save_as'] = Button(panel, 'Save As New Group: ', size=(150, -1),
                            action=self.on_saveas)
@@ -155,7 +157,7 @@ class OverAbsorptionDialog(wx.Dialog):
         panel.Add(wids['phi_out'])
 
         panel.Add(wids['correct'], newrow=True)
-        panel.Add(wids['apply'], dcol=2, newrow=True)
+        # panel.Add(wids['apply'], dcol=2, newrow=True)
 
         panel.Add(wids['save_as'], newrow=True)
         panel.Add(wids['save_as_name'], dcol=3)
@@ -301,10 +303,9 @@ class EnergyCalibrateDialog(wx.Dialog):
         self.plottype = Choice(panel, choices=list(Plot_Choices.keys()),
                                    size=(250, -1), action=self.plot_results)
 
-
-        apply_one = Button(panel, 'Save / Overwrite ', size=(150, -1),
-                           action=self.on_apply_one)
-        SetTip(apply_one, 'Save rebinned data, overwrite current arrays')
+        # apply_one = Button(panel, 'Save / Overwrite ', size=(150, -1),
+        #                   action=self.on_apply_one)
+        # SetTip(apply_one, 'Save rebinned data, overwrite current arrays')
 
         apply_sel = Button(panel, 'Apply Shift to Selected Groups',
                            size=(250, -1),  action=self.on_apply_sel)
@@ -349,7 +350,7 @@ overwriting current arrays''')
         panel.Add(wids['eshift'])
         add_text(' eV', newrow=False)
         panel.Add(HLine(panel, size=(500, 3)), dcol=4, newrow=True)
-        panel.Add(apply_one, newrow=True)
+        # panel.Add(apply_one, newrow=True)
 
         panel.Add(wids['save_as'], newrow=True)
         panel.Add(wids['save_as_name'], dcol=3)
@@ -514,9 +515,9 @@ overwriting current arrays''')
         ngroup = self.controller.copy_group(fname, new_filename=new_fname)
 
         ensure_en_orig(ngroup)
-
-        ngroup.energy_shift = eshift
         ngroup.xdat = ngroup.energy = eshift + ngroup.energy_orig[:]
+        ngroup.energy_shift = 0
+        ngroup.energy_ref = ngroup.groupname
 
         ogroup = self.controller.get_group(fname)
         self.parent.onNewGroup(ngroup, journal=ogroup.journal)
@@ -631,9 +632,9 @@ class RebinDataDialog(wx.Dialog):
             if wname != 'grouplist':
                 wid.SetAction(partial(self.on_rebin, name=wname))
 
-        wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
-                               action=self.on_apply)
-        SetTip(wids['apply'], 'Save rebinned data, overwrite current arrays')
+        #wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
+        #                       action=self.on_apply)
+        #SetTip(wids['apply'], 'Save rebinned data, overwrite current arrays')
 
         wids['save_as'] = Button(panel, 'Save As New Group: ', size=(150, -1),
                                  action=self.on_saveas)
@@ -676,7 +677,7 @@ class RebinDataDialog(wx.Dialog):
         panel.Add(wids['exafs_step'])
         add_text('1/\u212B', newrow=False)
 
-        panel.Add(wids['apply'], dcol=2, newrow=True)
+        # panel.Add(wids['apply'], dcol=2, newrow=True)
         panel.Add(wids['save_as'],  dcol=2, newrow=True)
         panel.Add(wids['save_as_name'], dcol=3)
         panel.Add(Button(panel, 'Done', size=(150, -1), action=self.onDone),
@@ -841,9 +842,9 @@ class SmoothDataDialog(wx.Dialog):
 
         self.message = SimpleText(panel, label='         ', size=(200, -1))
 
-        wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
-                               action=self.on_apply)
-        SetTip(wids['apply'], 'Save corrected data, overwrite current arrays')
+        # wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
+        #                       action=self.on_apply)
+        # SetTip(wids['apply'], 'Save corrected data, overwrite current arrays')
 
         wids['save_as'] = Button(panel, 'Save As New Group: ', size=(150, -1),
                            action=self.on_saveas)
@@ -873,7 +874,7 @@ class SmoothDataDialog(wx.Dialog):
         panel.Add((10, 10), newrow=True)
         panel.Add(self.message, dcol=5)
 
-        panel.Add(wids['apply'], newrow=True)
+        # panel.Add(wids['apply'], newrow=True)
 
         panel.Add(wids['save_as'],  newrow=True)
         panel.Add(wids['save_as_name'], dcol=5)
@@ -1022,10 +1023,9 @@ class DeconvolutionDialog(wx.Dialog):
         wids['esigma'] = FloatSpin(panel, value=0.5, digits=2, size=(90, -1),
                                    increment=0.1, action=self.on_deconvolve)
 
-
-        wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
-                               action=self.on_apply)
-        SetTip(wids['apply'], 'Save corrected data, overwrite current arrays')
+        #wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
+        #                       action=self.on_apply)
+        #SetTip(wids['apply'], 'Save corrected data, overwrite current arrays')
 
         wids['save_as'] = Button(panel, 'Save As New Group: ', size=(150, -1),
                            action=self.on_saveas)
@@ -1045,7 +1045,7 @@ class DeconvolutionDialog(wx.Dialog):
 
         add_text(' sigma= ')
         panel.Add(wids['esigma'])
-        panel.Add(wids['apply'], newrow=True)
+        # panel.Add(wids['apply'], newrow=True)
         panel.Add(wids['save_as'],  newrow=True)
         panel.Add(wids['save_as_name'], dcol=5)
         panel.Add(Button(panel, 'Done', size=(150, -1), action=self.onDone),
@@ -1171,10 +1171,10 @@ class DeglitchDialog(wx.Dialog):
 
         undo = Button(panel, 'Undo remove', size=(125, -1),
                       action=self.on_undo)
-        wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
-                               action=self.on_apply)
-        SetTip(wids['apply'], '''Save deglitched, overwrite current arrays,
-clear undo history''')
+        #wids['apply'] = Button(panel, 'Save / Overwrite', size=(150, -1),
+        #                       action=self.on_apply)
+        #SetTip(wids['apply'], '''Save deglitched, overwrite current arrays,
+#clear undo history''')
 
         wids['save_as'] = Button(panel, 'Save As New Group: ', size=(150, -1),
                                  action=self.on_saveas)
@@ -1198,10 +1198,15 @@ clear undo history''')
         self.choice_range = Choice(panel, choices=('above', 'below', 'between'),
                                     size=(90, -1), action=self.on_rangechoice)
 
+        self.choice_range.SetStringSelection('above')
+        wids['range2'].Disable()
+
         wids['plotopts'] = Choice(panel, choices=list(DEGLITCH_PLOTS.keys()),
                                   size=(175, -1),
                                   action=self.on_plotchoice)
 
+        wids['plotopts'].SetStringSelection(NORM_MU)
+
         def add_text(text, dcol=1, newrow=True):
             panel.Add(SimpleText(panel, text), dcol=dcol, newrow=newrow)
 
@@ -1226,14 +1231,15 @@ clear undo history''')
         panel.Add(wids['range2'])
         panel.Add(wids['range2_pin'])
 
-        panel.Add(wids['apply'], dcol=2, newrow=True)
-        panel.Add(self.history_message, dcol=2)
-        panel.Add(undo)
+        # panel.Add(wids['apply'], dcol=2, newrow=True)
 
         panel.Add(wids['save_as'], dcol=2, newrow=True)
         panel.Add(wids['save_as_name'], dcol=4)
         panel.Add(Button(panel, 'Done', size=(150, -1), action=self.onDone),
-                  newrow=True)
+                  dcol=2, newrow=True)
+        panel.Add(self.history_message, dcol=2)
+        panel.Add(undo)
+
         panel.pack()
 
         fit_dialog_window(self, panel)
@@ -1243,7 +1249,7 @@ clear undo history''')
         self.Destroy()
 
     def reset_data_history(self):
-        plottype = 'mu'
+        plottype = 'norm'
         if 'plotopts' in self.wids:
             plotstr = self.wids['plotopts'].GetStringSelection()
             plottype = DEGLITCH_PLOTS[plotstr]
@@ -1277,8 +1283,9 @@ clear undo history''')
         self.plot_results(use_zoom=True)
 
     def on_rangechoice(self, event=None):
-        if self.choice_range.GetStringSelection() == 'between':
-            self.wids['range2'].Enable()
+        sel = self.choice_range.GetStringSelection()
+        self.wids['range2'].Enable(sel == 'between')
+
 
     def on_plotchoice(self, event=None):
         plotstr = self.wids['plotopts'].GetStringSelection()
@@ -1401,7 +1408,7 @@ clear undo history''')
             s = '' if ex < 0 else '\n[%.1f]' % (etok(ex))
             return r"%1.4g%s" % (x, s)
 
-        set_zoomlimits(ppanel, zoom_limits, verbose=True) or ppanel.unzoom_all()
+        set_zoomlimits(ppanel, zoom_limits) or ppanel.unzoom_all()
         if plottype in ('chie', 'chiew'):
             ppanel.axes.xaxis.set_major_formatter(FuncFormatter(ek_formatter))
         ppanel.canvas.draw()
@@ -1845,6 +1852,10 @@ class RemoveDialog(wx.Dialog):
 
 class LoadSessionDialog(wx.Frame):
     """Read, show data from saved larch session"""
+
+    xasgroups_name = '_xasgroups'
+    feffgroups_name = ['_feffpaths', '_feffcache']
+
     def __init__(self, parent, session, filename, controller, **kws):
         self.parent = parent
         self.session = session
@@ -1889,12 +1900,22 @@ class LoadSessionDialog(wx.Frame):
         panel = GridPanel(rightpanel, ncols=3, nrows=4, pad=2, itemstyle=LEFT)
         self.wids = wids = {}
 
-
         top_message = 'Larch Session File: No XAFS Groups'
         symtable = controller.symtable
-        _xasgroups = getattr(symtable, '_xasgroups', None)
 
-        self.allgroups = session.symbols.get('_xasgroups', {})
+        self.allgroups = session.symbols.get(self.xasgroups_name, {})
+        self.extra_groups = []
+        for key, val in session.symbols.items():
+            if key == self.xasgroups_name or key in self.feffgroups_name:
+                continue
+            if key in self.allgroups:
+                continue
+            if hasattr(val, 'energy') and hasattr(val, 'mu'):
+                if key in self.allgroups.keys() or key in self.allgroups.values():
+                    continue
+                self.allgroups[key] = key
+                self.extra_groups.append(key)
+
 
         checked = []
         for fname, gname in self.allgroups.items():
@@ -1904,8 +1925,8 @@ class LoadSessionDialog(wx.Frame):
         self.grouplist.SetCheckedStrings(checked)
 
         group_names = list(self.allgroups.values())
-        group_names += ['_xasgroups', '_feffpaths', '_feffcache']
-
+        group_names.append(self.xasgroups_name)
+        group_names.extend(self.feffgroups_name)
 
         wids['view_conf'] = Button(panel, 'Show Session Configuration',
                                      size=(200, 30), action=self.onShowConfig)
@@ -1995,6 +2016,7 @@ class LoadSessionDialog(wx.Frame):
             ydat = getattr(grp, 'chi', xdef)
             ydat = ydat*xdat*xdat
             xlabel = plotlabels.chikw.format(2)
+
         if len(ydat) > 1:
             self.plotpanel.plot(xdat, ydat, xlabel=xlabel,
                                 ylabel=ylabel, title=fname)
@@ -2019,7 +2041,6 @@ class LoadSessionDialog(wx.Frame):
         self.Destroy()
 
     def onImport(self, event=None):
-
         ignore = []
         for gname, chbox in self.overwrite_checkboxes.items():
             if not chbox.IsChecked():
@@ -2030,20 +2051,25 @@ class LoadSessionDialog(wx.Frame):
             if fname not in sel_groups:
                 ignore.append(gname)
 
-        fname = self.filename.replace('\\','/')        
+        fname = self.filename.replace('\\','/')
         if fname.endswith('/'):
             fname = fname[:-1]
-        lcmd = f"load_session('{fname}')"
+        lcmd = [f"load_session('{fname}'"]
         if len(ignore) > 0:
             ignore = repr(ignore)
-            lcmd = f"load_session('{fname}', ignore_groups={ignore})"
+            lcmd.append(f", ignore_groups={ignore}")
+        if len(self.extra_groups) > 0:
+            extra = repr(self.extra_groups)
+            lcmd.append(f", include_xasgroups={extra}")
+
+        lcmd = ''.join(lcmd) + ')'
 
         cmds = ["# Loading Larch Session with ", lcmd, '######']
 
         self.controller.larch.eval('\n'.join(cmds))
-
         last_fname = None
-        for key, val in self.controller.symtable._xasgroups.items():
+        xasgroups = getattr(self.controller.symtable, self.xasgroups_name, {})
+        for key, val in xasgroups.items():
             if key not in self.controller.filelist.GetItems():
                 self.controller.filelist.Append(key)
                 last_fname = key
