@@ -24,7 +24,7 @@ feffit_report    create a report from feffit() results
 
 from .xafsutils import KTOE, ETOK, set_xafsGroup, etok, ktoe, guess_energy_units
 from .xafsft import xftf, xftr, xftf_fast, xftr_fast, ftwindow, xftf_prep
-from .pre_edge import pre_edge, preedge, find_e0
+from .pre_edge import pre_edge, preedge, find_e0, energy_align
 from .prepeaks import prepeaks_setup, pre_edge_baseline, prepeaks_fit
 from .feffdat import FeffDatFile, FeffPathGroup, feffpath, path2chi, ff2chi, use_feffpath
 from .feffit import (FeffitDataSet, TransformGroup, feffit,
@@ -64,6 +64,7 @@ _larch_builtins = {'_xafs': dict(autobk=autobk, etok=etok, ktoe=ktoe,
                                  xftf_prep=xftf_prep, xftf_fast=xftf_fast,
                                  xftr_fast=xftr_fast, ftwindow=ftwindow,
                                  find_e0=find_e0, pre_edge=pre_edge,
+                                 energy_align=energy_align,
                                  prepeaks_setup=prepeaks_setup,
                                  prepeaks_fit=prepeaks_fit,
                                  pre_edge_baseline=pre_edge_baseline,
