@@ -13,6 +13,7 @@ except:
 
 from xraydb import atomic_symbol, atomic_number, xray_edge
 from larch.io.fileutils import gformat
+from larch.utils.strutils import fix_varname, strict_ascii
 
 
 def get_atom_map(structure):
@@ -47,7 +48,7 @@ def read_cif_structure(ciftext):
     if not HAS_PYMATGEN:
         raise ImportError('pymatgen required')
     try:
-        cifstructs = CifParser(StringIO(ciftext))
+        cifstructs = CifParser(StringIO(ciftext), site_tolerance=5.e-4)
         parse_ok = True
         file_found = True
     except:
@@ -56,7 +57,7 @@ def read_cif_structure(ciftext):
         if os.path.exists(ciftext):
             file_found = True
             try:
-                cifstructs = CifParser(ciftext)
+                cifstructs = CifParser(ciftext, site_tolerance=5.e-4)
                 parse_ok = True
             except:
                 parse_ok = False
@@ -73,13 +74,29 @@ def read_cif_structure(ciftext):
             raise ValueError('invalid text of CIF file')
     return cstruct
 
-def cif_sites(ciftext):
+def cif_sites(ciftext, absorber=None):
     "return list of sites for the structure"
     cstruct = read_cif_structure(ciftext)
-    return cstruct.sites
+    out = cstruct.sites
+    if absorber is not None:
+        abname = absorber.lower()
+        out = []
+        for site in cstruct.sites:
+            species = site.species_string.lower()
+            if ',' in species and ':' in species: # multi-occupancy site
+                for siteocc in species.split(','):
+                    sname, occ = siteocc.split(':')
+                    if sname.strip() == abname:
+                        out.append(site)
+            elif species == abname:
+                out.append(site)
+        if len(out) == 0:
+            out = cstruct.sites[0]
+    return out
+
 
 def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
-                site_index=None, extra_titles=None, version8=True):
+                site_index=None, extra_titles=None, with_h=False, version8=True):
     """convert CIF text to Feff8 or Feff6l input file
 
     Arguments
@@ -91,6 +108,8 @@ def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
       cluster_size (float):     size of cluster, in Angstroms         [8.0]
       absorber_site (int):      index of site for absorber (see Note 3) [1]
       site_index (int or None): index of site for absorber (see Note 4) [None]
+      extra_titles (list of str or None): extra title lines to include [None]
+      with_h (bool):            whether to include H atoms [False]
       version8 (bool):          whether to write Feff8l input (see Note 5)[True]
     Returns
     -------
@@ -113,7 +132,10 @@ def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
       5. if version8 is False, outputs will be written for Feff6l
 
     """
-    cstruct = read_cif_structure(ciftext)
+    try:
+        cstruct = read_cif_structure(ciftext)
+    except ValueError:
+        return '# could not read CIF file'
 
     sgroup = SpacegroupAnalyzer(cstruct).get_symmetry_dataset()
     space_group = sgroup["international"]
@@ -128,7 +150,16 @@ def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
     edge_energy = xray_edge(absorber, edge).energy
     edge_comment = f'{absorber:s} {edge:s} edge, around {edge_energy:.0f} eV'
 
-    atoms_map = get_atom_map(cstruct)
+    unique_pot_atoms = []
+    for site in cstruct:
+        for elem in site.species.elements:
+            if elem.symbol not in unique_pot_atoms:
+                unique_pot_atoms.append(elem.symbol)
+
+    atoms_map = {}
+    for i, atom in enumerate(unique_pot_atoms):
+        atoms_map[atom] = i + 1
+
     if absorber not in atoms_map:
         atlist = ', '.join(atoms_map.keys())
         raise ValueError(f'atomic symbol {absorber:s} not listed in CIF data: ({atlist})')
@@ -155,6 +186,8 @@ def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
     if site_index is not None:
         absorber_index = site_index - 1
 
+    # print("Got sites ", len(cstruct.sites), len(site_atoms), len(site_tags))
+
     center = cstruct[absorber_index].coords
     sphere = cstruct.get_neighbors(cstruct[absorber_index], cluster_size)
     symbols = [absorber]
@@ -174,7 +207,6 @@ def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
 
     if extra_titles is not None:
         for etitle in extra_titles[:]:
-
             if not etitle.startswith('TITLE '):
                 etitle = 'TITLE ' + etitle
             out_text.append(etitle)
@@ -185,12 +217,13 @@ def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
 
     out_text.append('* crystallographics sites: note that these sites may not be unique!')
     out_text.append(f'*     using absorber at site {1+absorber_index:d} in the list below')
-    out_text.append(f'*     selected as "absorber=\'{absorber:s}\', absorber_site={absorber_site:d}" ')
+    out_text.append(f'*     selected as absorber="{absorber:s}", absorber_site={absorber_site:d}')
     out_text.append('* index   X        Y        Z      species')
     for i, site in enumerate(cstruct):
         fc = site.frac_coords
+        species_string = fix_varname(site.species_string.strip())
         marker = '  <- absorber' if  (i == absorber_index) else ''
-        out_text.append(f'* {i+1:3d}   {fc[0]:.6f} {fc[1]:.6f} {fc[2]:.6f}  {site.species_string:s} {marker:s}')
+        out_text.append(f'* {i+1:3d}   {fc[0]:.6f} {fc[1]:.6f} {fc[2]:.6f}  {species_string:s} {marker:s}')
 
     out_text.extend(['* ', '', ''])
 
@@ -200,11 +233,12 @@ def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
         out_text.append('CONTROL 1 1 1 1 1 1')
         out_text.append('PRINT   1 0 0 0 0 3')
         out_text.append('EXAFS   20.0')
+        out_text.append('NLEG     6')
         out_text.append(f'RPATH   {cluster_size:.2f}')
         out_text.append('*SCF    5.0')
-        
+
     else:
-        edge_index = {'K': 1, 'L1': 2, 'L2': 3, 'L3': 4}[edge]        
+        edge_index = {'K': 1, 'L1': 2, 'L2': 3, 'L3': 4}[edge]
         out_text.append(f'HOLE    {edge_index:d}  1.0  * {edge_comment:s} (2nd number is S02)')
         out_text.append('CONTROL 1 1 1 0 * phase, paths, feff, chi')
         out_text.append('PRINT   1 0 0 0')
@@ -212,24 +246,33 @@ def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
 
     out_text.extend(['', 'EXCHANGE 0', '',
                      '*  POLARIZATION  0 0 0', '',
-                     'POTENTIALS',
-                     '*    IPOT  Z   Tag'])
+                     'POTENTIALS',  '*    IPOT  Z   Tag'])
+
+    # loop to find atoms actually in cluster, in case some atom
+    # (maybe fractional occupation) is not included
+
+    at_lines = [(0, cluster[0].x, cluster[0].y, cluster[0].z, 0, absorber, tags[0])]
+    ipot_map = {}
+    next_ipot = 0
+    for i, site in enumerate(cluster[1:]):
+        sym = site.species_string
+        if sym == 'H' and not with_h:
+            continue
+        if sym in ipot_map:
+            ipot = ipot_map[sym]
+        else:
+            next_ipot += 1
+            ipot_map[sym] = ipot = next_ipot
+
+        dist = cluster.get_distance(0, i+1)
+        at_lines.append((dist, site.x, site.y, site.z, ipot, sym, tags[i+1]))
+
 
     ipot, z = 0, absorber_z
     out_text.append(f'   {ipot:4d}  {z:4d}   {absorber:s}')
-    for tag in atoms_map.keys():
-        ipot += 1
-        z = atomic_number(tag)
-        out_text.append(f'   {ipot:4d}  {z:4d}   {tag:s}')
-
-
-    at_lines = [(0, cluster[0].x, cluster[0].y, cluster[0].z, 0, absorber, tags[0])]
-
-    for i, site in enumerate(cluster[1:]):
-        sym = site.species_string
-        ipot = atoms_map[site.species_string]
-        dist = cluster.get_distance(0, i+1)
-        at_lines.append((dist, site.x, site.y, site.z, ipot, sym, tags[i+1]))
+    for sym, ipot in ipot_map.items():
+        z = atomic_number(sym)
+        out_text.append(f'   {ipot:4d}  {z:4d}   {sym:s}')
 
     out_text.append('')
     out_text.append('ATOMS')
@@ -246,4 +289,4 @@ def cif2feffinp(ciftext, absorber, edge=None, cluster_size=8.0, absorber_site=1,
     out_text.append('')
     out_text.append('* END')
     out_text.append('')
-    return '\n'.join(out_text)
+    return strict_ascii('\n'.join(out_text))
