@@ -82,7 +82,7 @@ QAXIS = np.arange(QMIN, QMAX+QSTEP, QSTEP)
 ENERGY = 19000 ## units eV
 _cifdb = None
 
-def get_cifdb(dbname='amcsd_cif.db', _larch=None):
+def get_cifdb(dbname='amcsd_cif0.db', _larch=None):
     global _cifdb
     if _cifdb is None:
         _cifdb = cifDB(dbname=dbname)
@@ -197,7 +197,7 @@ class cifDB(object):
     def create_cifdb(self,name=None,verbose=False):
 
         if name is None:
-            self.dbname = 'amcsd%02d.db'
+            self.dbname = 'amcsd_cif0.db'
             counter = 0
             while os.path.exists(self.dbname % counter):
                 counter += 1
@@ -397,8 +397,8 @@ class cifDB(object):
         if url:
             cifstr = requests.get(ciffile).text
         else:
-            with open(ciffile,'r') as file:
-                cifstr = str(file.read())
+            with open(ciffile,'rb') as file:
+                cifstr = str(file.read().decode('utf-8'))
         cif = create_xrdcif(text=cifstr)
 
         if cif.id_no is None:
